# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict

from .._models import BaseModel

__all__ = ["DatasliceGetTagVdbDistributionResponse"]


class DatasliceGetTagVdbDistributionResponse(BaseModel):
    tag_distribution: Dict[str, int]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.


from .._models import BaseModel

__all__ = ["ClassifyBulkClassifyResponse"]


class ClassifyBulkClassifyResponse(BaseModel):
    message: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.


from .._models import BaseModel

__all__ = ["DatasliceCreateResponse"]


class DatasliceCreateResponse(BaseModel):
    dataslice_id: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Iterable, Optional
from typing_extensions import Literal

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import (
    maybe_transform,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.metadata import deasy_select_query_params

__all__ = ["DeasySelectResource", "AsyncDeasySelectResource"]


class DeasySelectResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> DeasySelectResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return DeasySelectResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DeasySelectResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return DeasySelectResourceWithStreamingResponse(self)

    def query(
        self,
        *,
        query: str,
        vdb_profile_name: str,
        max_filter_values_to_choose: Optional[int] | NotGiven = NOT_GIVEN,
        max_filters_to_choose: Optional[int] | NotGiven = NOT_GIVEN,
        max_search_reduction: Optional[float] | NotGiven = NOT_GIVEN,
        min_filter_values_to_choose: Optional[int] | NotGiven = NOT_GIVEN,
        min_filters_to_choose: Optional[int] | NotGiven = NOT_GIVEN,
        min_search_reduction: Optional[float] | NotGiven = NOT_GIVEN,
        return_type: Optional[Literal["results", "condition", "both"]] | NotGiven = NOT_GIVEN,
        tag_distributions: Optional[deasy_select_query_params.TagDistributions] | NotGiven = NOT_GIVEN,
        tag_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        tag_schemas: Optional[Iterable[deasy_select_query_params.TagSchema]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Deasy Select Query

        Args:
          tag_distributions: Complete tag distribution data structure for analyzing filter impacts.

              Maps field names to their value distributions. Used for estimating search
              reductions without executing filters.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/metadata/deasy_select/query",
            body=maybe_transform(
                {
                    "query": query,
                    "vdb_profile_name": vdb_profile_name,
                    "max_filter_values_to_choose": max_filter_values_to_choose,
                    "max_filters_to_choose": max_filters_to_choose,
                    "max_search_reduction": max_search_reduction,
                    "min_filter_values_to_choose": min_filter_values_to_choose,
                    "min_filters_to_choose": min_filters_to_choose,
                    "min_search_reduction": min_search_reduction,
                    "return_type": return_type,
                    "tag_distributions": tag_distributions,
                    "tag_names": tag_names,
                    "tag_schemas": tag_schemas,
                },
                deasy_select_query_params.DeasySelectQueryParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncDeasySelectResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncDeasySelectResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return AsyncDeasySelectResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDeasySelectResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return AsyncDeasySelectResourceWithStreamingResponse(self)

    async def query(
        self,
        *,
        query: str,
        vdb_profile_name: str,
        max_filter_values_to_choose: Optional[int] | NotGiven = NOT_GIVEN,
        max_filters_to_choose: Optional[int] | NotGiven = NOT_GIVEN,
        max_search_reduction: Optional[float] | NotGiven = NOT_GIVEN,
        min_filter_values_to_choose: Optional[int] | NotGiven = NOT_GIVEN,
        min_filters_to_choose: Optional[int] | NotGiven = NOT_GIVEN,
        min_search_reduction: Optional[float] | NotGiven = NOT_GIVEN,
        return_type: Optional[Literal["results", "condition", "both"]] | NotGiven = NOT_GIVEN,
        tag_distributions: Optional[deasy_select_query_params.TagDistributions] | NotGiven = NOT_GIVEN,
        tag_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        tag_schemas: Optional[Iterable[deasy_select_query_params.TagSchema]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Deasy Select Query

        Args:
          tag_distributions: Complete tag distribution data structure for analyzing filter impacts.

              Maps field names to their value distributions. Used for estimating search
              reductions without executing filters.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/metadata/deasy_select/query",
            body=await async_maybe_transform(
                {
                    "query": query,
                    "vdb_profile_name": vdb_profile_name,
                    "max_filter_values_to_choose": max_filter_values_to_choose,
                    "max_filters_to_choose": max_filters_to_choose,
                    "max_search_reduction": max_search_reduction,
                    "min_filter_values_to_choose": min_filter_values_to_choose,
                    "min_filters_to_choose": min_filters_to_choose,
                    "min_search_reduction": min_search_reduction,
                    "return_type": return_type,
                    "tag_distributions": tag_distributions,
                    "tag_names": tag_names,
                    "tag_schemas": tag_schemas,
                },
                deasy_select_query_params.DeasySelectQueryParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class DeasySelectResourceWithRawResponse:
    def __init__(self, deasy_select: DeasySelectResource) -> None:
        self._deasy_select = deasy_select

        self.query = to_raw_response_wrapper(
            deasy_select.query,
        )


class AsyncDeasySelectResourceWithRawResponse:
    def __init__(self, deasy_select: AsyncDeasySelectResource) -> None:
        self._deasy_select = deasy_select

        self.query = async_to_raw_response_wrapper(
            deasy_select.query,
        )


class DeasySelectResourceWithStreamingResponse:
    def __init__(self, deasy_select: DeasySelectResource) -> None:
        self._deasy_select = deasy_select

        self.query = to_streamed_response_wrapper(
            deasy_select.query,
        )


class AsyncDeasySelectResourceWithStreamingResponse:
    def __init__(self, deasy_select: AsyncDeasySelectResource) -> None:
        self._deasy_select = deasy_select

        self.query = async_to_streamed_response_wrapper(
            deasy_select.query,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from deasy_client import Deasy, AsyncDeasy
from deasy_client._utils import parse_datetime

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestDeasySelect:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_query(self, client: Deasy) -> None:
        deasy_select = client.metadata.deasy_select.query(
            query="query",
            vdb_profile_name="vdb_profile_name",
        )
        assert_matches_type(object, deasy_select, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_query_with_all_params(self, client: Deasy) -> None:
        deasy_select = client.metadata.deasy_select.query(
            query="query",
            vdb_profile_name="vdb_profile_name",
            max_filter_values_to_choose=0,
            max_filters_to_choose=0,
            max_search_reduction=0,
            min_filter_values_to_choose=0,
            min_filters_to_choose=0,
            min_search_reduction=0,
            return_type="results",
            tag_distributions={
                "data": {
                    "foo": {
                        "values": {
                            "foo": {
                                "file_count": 0,
                                "chunk_count": 0,
                                "percentage": 0,
                            }
                        },
                        "coverage_percentage": 0,
                        "total_count": 0,
                    }
                }
            },
            tag_names=["string"],
            tag_schemas=[
                {
                    "description": "description",
                    "name": "name",
                    "output_type": "output_type",
                    "available_values": ["string"],
                    "created_at": parse_datetime("2019-12-27T18:11:19.117Z"),
                    "date_format": "date_format",
                    "examples": ["string"],
                    "max_values": 0,
                    "neg_examples": ["string"],
                    "retry_feedback": {"foo": "bar"},
                    "tag_id": "tag_id",
                    "tuned": 0,
                    "updated_at": parse_datetime("2019-12-27T18:11:19.117Z"),
                    "username": "username",
                }
            ],
        )
        assert_matches_type(object, deasy_select, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_query(self, client: Deasy) -> None:
        response = client.metadata.deasy_select.with_raw_response.query(
            query="query",
            vdb_profile_name="vdb_profile_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deasy_select = response.parse()
        assert_matches_type(object, deasy_select, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_query(self, client: Deasy) -> None:
        with client.metadata.deasy_select.with_streaming_response.query(
            query="query",
            vdb_profile_name="vdb_profile_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deasy_select = response.parse()
            assert_matches_type(object, deasy_select, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncDeasySelect:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_query(self, async_client: AsyncDeasy) -> None:
        deasy_select = await async_client.metadata.deasy_select.query(
            query="query",
            vdb_profile_name="vdb_profile_name",
        )
        assert_matches_type(object, deasy_select, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_query_with_all_params(self, async_client: AsyncDeasy) -> None:
        deasy_select = await async_client.metadata.deasy_select.query(
            query="query",
            vdb_profile_name="vdb_profile_name",
            max_filter_values_to_choose=0,
            max_filters_to_choose=0,
            max_search_reduction=0,
            min_filter_values_to_choose=0,
            min_filters_to_choose=0,
            min_search_reduction=0,
            return_type="results",
            tag_distributions={
                "data": {
                    "foo": {
                        "values": {
                            "foo": {
                                "file_count": 0,
                                "chunk_count": 0,
                                "percentage": 0,
                            }
                        },
                        "coverage_percentage": 0,
                        "total_count": 0,
                    }
                }
            },
            tag_names=["string"],
            tag_schemas=[
                {
                    "description": "description",
                    "name": "name",
                    "output_type": "output_type",
                    "available_values": ["string"],
                    "created_at": parse_datetime("2019-12-27T18:11:19.117Z"),
                    "date_format": "date_format",
                    "examples": ["string"],
                    "max_values": 0,
                    "neg_examples": ["string"],
                    "retry_feedback": {"foo": "bar"},
                    "tag_id": "tag_id",
                    "tuned": 0,
                    "updated_at": parse_datetime("2019-12-27T18:11:19.117Z"),
                    "username": "username",
                }
            ],
        )
        assert_matches_type(object, deasy_select, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_query(self, async_client: AsyncDeasy) -> None:
        response = await async_client.metadata.deasy_select.with_raw_response.query(
            query="query",
            vdb_profile_name="vdb_profile_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        deasy_select = await response.parse()
        assert_matches_type(object, deasy_select, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_query(self, async_client: AsyncDeasy) -> None:
        async with async_client.metadata.deasy_select.with_streaming_response.query(
            query="query",
            vdb_profile_name="vdb_profile_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            deasy_select = await response.parse()
            assert_matches_type(object, deasy_select, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .tags import (
    TagsResource,
    AsyncTagsResource,
    TagsResourceWithRawResponse,
    AsyncTagsResourceWithRawResponse,
    TagsResourceWithStreamingResponse,
    AsyncTagsResourceWithStreamingResponse,
)
from .graph import (
    GraphResource,
    AsyncGraphResource,
    GraphResourceWithRawResponse,
    AsyncGraphResourceWithRawResponse,
    GraphResourceWithStreamingResponse,
    AsyncGraphResourceWithStreamingResponse,
)
from .classify import (
    ClassifyResource,
    AsyncClassifyResource,
    ClassifyResourceWithRawResponse,
    AsyncClassifyResourceWithRawResponse,
    ClassifyResourceWithStreamingResponse,
    AsyncClassifyResourceWithStreamingResponse,
)
from .metadata import (
    MetadataResource,
    AsyncMetadataResource,
    MetadataResourceWithRawResponse,
    AsyncMetadataResourceWithRawResponse,
    MetadataResourceWithStreamingResponse,
    AsyncMetadataResourceWithStreamingResponse,
)
from .dataslice import (
    DatasliceResource,
    AsyncDatasliceResource,
    DatasliceResourceWithRawResponse,
    AsyncDatasliceResourceWithRawResponse,
    DatasliceResourceWithStreamingResponse,
    AsyncDatasliceResourceWithStreamingResponse,
)
from .prepare_data import (
    PrepareDataResource,
    AsyncPrepareDataResource,
    PrepareDataResourceWithRawResponse,
    AsyncPrepareDataResourceWithRawResponse,
    PrepareDataResourceWithStreamingResponse,
    AsyncPrepareDataResourceWithStreamingResponse,
)
from .classify_bulk import (
    ClassifyBulkResource,
    AsyncClassifyBulkResource,
    ClassifyBulkResourceWithRawResponse,
    AsyncClassifyBulkResourceWithRawResponse,
    ClassifyBulkResourceWithStreamingResponse,
    AsyncClassifyBulkResourceWithStreamingResponse,
)
from .llm_connector import (
    LlmConnectorResource,
    AsyncLlmConnectorResource,
    LlmConnectorResourceWithRawResponse,
    AsyncLlmConnectorResourceWithRawResponse,
    LlmConnectorResourceWithStreamingResponse,
    AsyncLlmConnectorResourceWithStreamingResponse,
)
from .vdb_connector import (
    VdbConnectorResource,
    AsyncVdbConnectorResource,
    VdbConnectorResourceWithRawResponse,
    AsyncVdbConnectorResourceWithRawResponse,
    VdbConnectorResourceWithStreamingResponse,
    AsyncVdbConnectorResourceWithStreamingResponse,
)
from .suggest_schema import (
    SuggestSchemaResource,
    AsyncSuggestSchemaResource,
    SuggestSchemaResourceWithRawResponse,
    AsyncSuggestSchemaResourceWithRawResponse,
    SuggestSchemaResourceWithStreamingResponse,
    AsyncSuggestSchemaResourceWithStreamingResponse,
)
from .suggest_description import (
    SuggestDescriptionResource,
    AsyncSuggestDescriptionResource,
    SuggestDescriptionResourceWithRawResponse,
    AsyncSuggestDescriptionResourceWithRawResponse,
    SuggestDescriptionResourceWithStreamingResponse,
    AsyncSuggestDescriptionResourceWithStreamingResponse,
)

__all__ = [
    "ClassifyBulkResource",
    "AsyncClassifyBulkResource",
    "ClassifyBulkResourceWithRawResponse",
    "AsyncClassifyBulkResourceWithRawResponse",
    "ClassifyBulkResourceWithStreamingResponse",
    "AsyncClassifyBulkResourceWithStreamingResponse",
    "ClassifyResource",
    "AsyncClassifyResource",
    "ClassifyResourceWithRawResponse",
    "AsyncClassifyResourceWithRawResponse",
    "ClassifyResourceWithStreamingResponse",
    "AsyncClassifyResourceWithStreamingResponse",
    "PrepareDataResource",
    "AsyncPrepareDataResource",
    "PrepareDataResourceWithRawResponse",
    "AsyncPrepareDataResourceWithRawResponse",
    "PrepareDataResourceWithStreamingResponse",
    "AsyncPrepareDataResourceWithStreamingResponse",
    "SuggestSchemaResource",
    "AsyncSuggestSchemaResource",
    "SuggestSchemaResourceWithRawResponse",
    "AsyncSuggestSchemaResourceWithRawResponse",
    "SuggestSchemaResourceWithStreamingResponse",
    "AsyncSuggestSchemaResourceWithStreamingResponse",
    "SuggestDescriptionResource",
    "AsyncSuggestDescriptionResource",
    "SuggestDescriptionResourceWithRawResponse",
    "AsyncSuggestDescriptionResourceWithRawResponse",
    "SuggestDescriptionResourceWithStreamingResponse",
    "AsyncSuggestDescriptionResourceWithStreamingResponse",
    "TagsResource",
    "AsyncTagsResource",
    "TagsResourceWithRawResponse",
    "AsyncTagsResourceWithRawResponse",
    "TagsResourceWithStreamingResponse",
    "AsyncTagsResourceWithStreamingResponse",
    "MetadataResource",
    "AsyncMetadataResource",
    "MetadataResourceWithRawResponse",
    "AsyncMetadataResourceWithRawResponse",
    "MetadataResourceWithStreamingResponse",
    "AsyncMetadataResourceWithStreamingResponse",
    "VdbConnectorResource",
    "AsyncVdbConnectorResource",
    "VdbConnectorResourceWithRawResponse",
    "AsyncVdbConnectorResourceWithRawResponse",
    "VdbConnectorResourceWithStreamingResponse",
    "AsyncVdbConnectorResourceWithStreamingResponse",
    "LlmConnectorResource",
    "AsyncLlmConnectorResource",
    "LlmConnectorResourceWithRawResponse",
    "AsyncLlmConnectorResourceWithRawResponse",
    "LlmConnectorResourceWithStreamingResponse",
    "AsyncLlmConnectorResourceWithStreamingResponse",
    "DatasliceResource",
    "AsyncDatasliceResource",
    "DatasliceResourceWithRawResponse",
    "AsyncDatasliceResourceWithRawResponse",
    "DatasliceResourceWithStreamingResponse",
    "AsyncDatasliceResourceWithStreamingResponse",
    "GraphResource",
    "AsyncGraphResource",
    "GraphResourceWithRawResponse",
    "AsyncGraphResourceWithRawResponse",
    "GraphResourceWithStreamingResponse",
    "AsyncGraphResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Optional
from typing_extensions import Literal

import httpx

from ..types import suggest_schema_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.condition_input_param import ConditionInputParam
from ..types.suggest_schema_create_response import SuggestSchemaCreateResponse

__all__ = ["SuggestSchemaResource", "AsyncSuggestSchemaResource"]


class SuggestSchemaResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SuggestSchemaResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return SuggestSchemaResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SuggestSchemaResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return SuggestSchemaResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        vdb_profile_name: str,
        condition: Optional[ConditionInputParam] | NotGiven = NOT_GIVEN,
        context_level: Optional[str] | NotGiven = NOT_GIVEN,
        current_tree: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        file_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        graph_tag_type: Optional[Literal["open_ended", "binary", "mixed", "defined_values"]] | NotGiven = NOT_GIVEN,
        llm_profile_name: Optional[str] | NotGiven = NOT_GIVEN,
        max_height: Optional[int] | NotGiven = NOT_GIVEN,
        max_tags_per_level: Optional[int] | NotGiven = NOT_GIVEN,
        min_tags_per_level: Optional[int] | NotGiven = NOT_GIVEN,
        node: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        set_max_values: Optional[bool] | NotGiven = NOT_GIVEN,
        use_existing_tags: Optional[bool] | NotGiven = NOT_GIVEN,
        use_extracted_tags: Optional[bool] | NotGiven = NOT_GIVEN,
        user_context: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SuggestSchemaCreateResponse:
        """
        Suggest a hierarchical tag schema based on file content and existing metadata

        Attributes:

            vdb_profile_name: The name of the vector database profile to use for accessing file content.
            llm_profile_name: Optional name of the language model profile to use for generating suggestions. Defaults to DeasyLabs compute
            file_names: Optional list of specific files to analyze for the hierarchy suggestion.
            dataslice_id: Optional ID of a dataslice to pull files from for the hierarchy suggestion.
            current_tree: Optional existing hierarchy tree to build upon.
            node: Optional node location of the existing hierarchy tree to build upon.
            condition: Optional filtering condition to select specific files for analysis.
            user_context: Optional user-provided context to guide the suggestion process.
            context_level: Level at which to analyze content ('file' or 'chunk'). Defaults to 'file'.
            max_height: Maximum depth of the generated hierarchy tree. Defaults to 2.
            use_existing_tags: Whether to incorporate existing tags in suggestions. Defaults to False.
            use_extracted_tags: Whether to use previously extracted tags. Defaults to False.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/suggest_schema",
            body=maybe_transform(
                {
                    "vdb_profile_name": vdb_profile_name,
                    "condition": condition,
                    "context_level": context_level,
                    "current_tree": current_tree,
                    "dataslice_id": dataslice_id,
                    "file_names": file_names,
                    "graph_tag_type": graph_tag_type,
                    "llm_profile_name": llm_profile_name,
                    "max_height": max_height,
                    "max_tags_per_level": max_tags_per_level,
                    "min_tags_per_level": min_tags_per_level,
                    "node": node,
                    "set_max_values": set_max_values,
                    "use_existing_tags": use_existing_tags,
                    "use_extracted_tags": use_extracted_tags,
                    "user_context": user_context,
                },
                suggest_schema_create_params.SuggestSchemaCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SuggestSchemaCreateResponse,
        )


class AsyncSuggestSchemaResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSuggestSchemaResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return AsyncSuggestSchemaResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSuggestSchemaResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return AsyncSuggestSchemaResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        vdb_profile_name: str,
        condition: Optional[ConditionInputParam] | NotGiven = NOT_GIVEN,
        context_level: Optional[str] | NotGiven = NOT_GIVEN,
        current_tree: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        file_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        graph_tag_type: Optional[Literal["open_ended", "binary", "mixed", "defined_values"]] | NotGiven = NOT_GIVEN,
        llm_profile_name: Optional[str] | NotGiven = NOT_GIVEN,
        max_height: Optional[int] | NotGiven = NOT_GIVEN,
        max_tags_per_level: Optional[int] | NotGiven = NOT_GIVEN,
        min_tags_per_level: Optional[int] | NotGiven = NOT_GIVEN,
        node: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        set_max_values: Optional[bool] | NotGiven = NOT_GIVEN,
        use_existing_tags: Optional[bool] | NotGiven = NOT_GIVEN,
        use_extracted_tags: Optional[bool] | NotGiven = NOT_GIVEN,
        user_context: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SuggestSchemaCreateResponse:
        """
        Suggest a hierarchical tag schema based on file content and existing metadata

        Attributes:

            vdb_profile_name: The name of the vector database profile to use for accessing file content.
            llm_profile_name: Optional name of the language model profile to use for generating suggestions. Defaults to DeasyLabs compute
            file_names: Optional list of specific files to analyze for the hierarchy suggestion.
            dataslice_id: Optional ID of a dataslice to pull files from for the hierarchy suggestion.
            current_tree: Optional existing hierarchy tree to build upon.
            node: Optional node location of the existing hierarchy tree to build upon.
            condition: Optional filtering condition to select specific files for analysis.
            user_context: Optional user-provided context to guide the suggestion process.
            context_level: Level at which to analyze content ('file' or 'chunk'). Defaults to 'file'.
            max_height: Maximum depth of the generated hierarchy tree. Defaults to 2.
            use_existing_tags: Whether to incorporate existing tags in suggestions. Defaults to False.
            use_extracted_tags: Whether to use previously extracted tags. Defaults to False.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/suggest_schema",
            body=await async_maybe_transform(
                {
                    "vdb_profile_name": vdb_profile_name,
                    "condition": condition,
                    "context_level": context_level,
                    "current_tree": current_tree,
                    "dataslice_id": dataslice_id,
                    "file_names": file_names,
                    "graph_tag_type": graph_tag_type,
                    "llm_profile_name": llm_profile_name,
                    "max_height": max_height,
                    "max_tags_per_level": max_tags_per_level,
                    "min_tags_per_level": min_tags_per_level,
                    "node": node,
                    "set_max_values": set_max_values,
                    "use_existing_tags": use_existing_tags,
                    "use_extracted_tags": use_extracted_tags,
                    "user_context": user_context,
                },
                suggest_schema_create_params.SuggestSchemaCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SuggestSchemaCreateResponse,
        )


class SuggestSchemaResourceWithRawResponse:
    def __init__(self, suggest_schema: SuggestSchemaResource) -> None:
        self._suggest_schema = suggest_schema

        self.create = to_raw_response_wrapper(
            suggest_schema.create,
        )


class AsyncSuggestSchemaResourceWithRawResponse:
    def __init__(self, suggest_schema: AsyncSuggestSchemaResource) -> None:
        self._suggest_schema = suggest_schema

        self.create = async_to_raw_response_wrapper(
            suggest_schema.create,
        )


class SuggestSchemaResourceWithStreamingResponse:
    def __init__(self, suggest_schema: SuggestSchemaResource) -> None:
        self._suggest_schema = suggest_schema

        self.create = to_streamed_response_wrapper(
            suggest_schema.create,
        )


class AsyncSuggestSchemaResourceWithStreamingResponse:
    def __init__(self, suggest_schema: AsyncSuggestSchemaResource) -> None:
        self._suggest_schema = suggest_schema

        self.create = async_to_streamed_response_wrapper(
            suggest_schema.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["SuggestSchemaCreateParams"]


class SuggestSchemaCreateParams(TypedDict, total=False):
    vdb_profile_name: Required[str]

    condition: Optional["ConditionInputParam"]

    context_level: Optional[str]

    current_tree: Optional[Dict[str, object]]

    dataslice_id: Optional[str]

    file_names: Optional[List[str]]

    graph_tag_type: Optional[Literal["open_ended", "binary", "mixed", "defined_values"]]

    llm_profile_name: Optional[str]

    max_height: Optional[int]

    max_tags_per_level: Optional[int]

    min_tags_per_level: Optional[int]

    node: Optional[Dict[str, object]]

    set_max_values: Optional[bool]

    use_existing_tags: Optional[bool]

    use_extracted_tags: Optional[bool]

    user_context: Optional[str]


from .condition_input_param import ConditionInputParam



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Union, Optional
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["TagUpdateParams", "TagData"]


class TagUpdateParams(TypedDict, total=False):
    tag_data: Required[TagData]


class TagData(TypedDict, total=False):
    name: Required[str]

    output_type: Required[str]

    available_values: Optional[List[str]]

    date_format: Optional[str]

    description: Optional[str]

    examples: Optional[List[Union[Dict[str, object], str]]]

    max_values: Annotated[Optional[int], PropertyInfo(alias="maxValues")]

    tag_id: Optional[str]

    tuned: Optional[int]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

import httpx

from ..types import prepare_data_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.prepare_data_create_response import PrepareDataCreateResponse

__all__ = ["PrepareDataResource", "AsyncPrepareDataResource"]


class PrepareDataResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PrepareDataResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return PrepareDataResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PrepareDataResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return PrepareDataResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        vdb_profile_name: str,
        llm_profile_name: Optional[str] | NotGiven = NOT_GIVEN,
        total_data_sets: Optional[int] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PrepareDataCreateResponse:
        """
        Prepare data to enable Deasy auto-suggestions

        Attributes:

            vdb_profile_name: The name of the vdb profile to use for classification.
            llm_profile_name: The name of the llm profile to use for classification.
            total_data_sets: The total number of files that will be prepared.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/prepare_data",
            body=maybe_transform(
                {
                    "vdb_profile_name": vdb_profile_name,
                    "llm_profile_name": llm_profile_name,
                    "total_data_sets": total_data_sets,
                },
                prepare_data_create_params.PrepareDataCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PrepareDataCreateResponse,
        )


class AsyncPrepareDataResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPrepareDataResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return AsyncPrepareDataResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPrepareDataResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return AsyncPrepareDataResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        vdb_profile_name: str,
        llm_profile_name: Optional[str] | NotGiven = NOT_GIVEN,
        total_data_sets: Optional[int] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PrepareDataCreateResponse:
        """
        Prepare data to enable Deasy auto-suggestions

        Attributes:

            vdb_profile_name: The name of the vdb profile to use for classification.
            llm_profile_name: The name of the llm profile to use for classification.
            total_data_sets: The total number of files that will be prepared.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/prepare_data",
            body=await async_maybe_transform(
                {
                    "vdb_profile_name": vdb_profile_name,
                    "llm_profile_name": llm_profile_name,
                    "total_data_sets": total_data_sets,
                },
                prepare_data_create_params.PrepareDataCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PrepareDataCreateResponse,
        )


class PrepareDataResourceWithRawResponse:
    def __init__(self, prepare_data: PrepareDataResource) -> None:
        self._prepare_data = prepare_data

        self.create = to_raw_response_wrapper(
            prepare_data.create,
        )


class AsyncPrepareDataResourceWithRawResponse:
    def __init__(self, prepare_data: AsyncPrepareDataResource) -> None:
        self._prepare_data = prepare_data

        self.create = async_to_raw_response_wrapper(
            prepare_data.create,
        )


class PrepareDataResourceWithStreamingResponse:
    def __init__(self, prepare_data: PrepareDataResource) -> None:
        self._prepare_data = prepare_data

        self.create = to_streamed_response_wrapper(
            prepare_data.create,
        )


class AsyncPrepareDataResourceWithStreamingResponse:
    def __init__(self, prepare_data: AsyncPrepareDataResource) -> None:
        self._prepare_data = prepare_data

        self.create = async_to_streamed_response_wrapper(
            prepare_data.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List
from datetime import datetime

from .._models import BaseModel

__all__ = ["GraphListResponse", "Graph"]


class Graph(BaseModel):
    created_at: datetime

    graph_data: Dict[str, object]

    graph_description: str

    graph_id: str

    graph_name: str

    updated_at: datetime

    user_id: str


class GraphListResponse(BaseModel):
    graphs: List[Graph]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .metadata import (
    MetadataResource,
    AsyncMetadataResource,
    MetadataResourceWithRawResponse,
    AsyncMetadataResourceWithRawResponse,
    MetadataResourceWithStreamingResponse,
    AsyncMetadataResourceWithStreamingResponse,
)
from .deasy_select import (
    DeasySelectResource,
    AsyncDeasySelectResource,
    DeasySelectResourceWithRawResponse,
    AsyncDeasySelectResourceWithRawResponse,
    DeasySelectResourceWithStreamingResponse,
    AsyncDeasySelectResourceWithStreamingResponse,
)

__all__ = [
    "DeasySelectResource",
    "AsyncDeasySelectResource",
    "DeasySelectResourceWithRawResponse",
    "AsyncDeasySelectResourceWithRawResponse",
    "DeasySelectResourceWithStreamingResponse",
    "AsyncDeasySelectResourceWithStreamingResponse",
    "MetadataResource",
    "AsyncMetadataResource",
    "MetadataResourceWithRawResponse",
    "AsyncMetadataResourceWithRawResponse",
    "MetadataResourceWithStreamingResponse",
    "AsyncMetadataResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import (
    llm_connector_create_params,
    llm_connector_delete_params,
    llm_connector_update_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.connector_response import ConnectorResponse
from ..types.openai_config_param import OpenAIConfigParam
from ..types.llm_connector_list_response import LlmConnectorListResponse

__all__ = ["LlmConnectorResource", "AsyncLlmConnectorResource"]


class LlmConnectorResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> LlmConnectorResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return LlmConnectorResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> LlmConnectorResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return LlmConnectorResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        connector_body: OpenAIConfigParam,
        connector_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ConnectorResponse:
        """
        Create a new llm connector

        Attributes:

            connector_name: The profile name of the connector to create.
            connector_body: The body of the connector to create.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/llm_connector/create",
            body=maybe_transform(
                {
                    "connector_body": connector_body,
                    "connector_name": connector_name,
                },
                llm_connector_create_params.LlmConnectorCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConnectorResponse,
        )

    def update(
        self,
        *,
        connector_body: OpenAIConfigParam,
        connector_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ConnectorResponse:
        """
        Update a llm connector

        Attributes:

            connector_name: The profile name of the connector to update.
            connector_body: The body of the connector to update.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/llm_connector/update",
            body=maybe_transform(
                {
                    "connector_body": connector_body,
                    "connector_name": connector_name,
                },
                llm_connector_update_params.LlmConnectorUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConnectorResponse,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LlmConnectorListResponse:
        """List all the llm connectors"""
        return self._post(
            "/llm_connector/list",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LlmConnectorListResponse,
        )

    def delete(
        self,
        *,
        connector_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ConnectorResponse:
        """
        Delete a llm connector

        Attributes:

            connector_name: The profile name of the connector to delete.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/llm_connector/delete",
            body=maybe_transform(
                {"connector_name": connector_name}, llm_connector_delete_params.LlmConnectorDeleteParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConnectorResponse,
        )


class AsyncLlmConnectorResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncLlmConnectorResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return AsyncLlmConnectorResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncLlmConnectorResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return AsyncLlmConnectorResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        connector_body: OpenAIConfigParam,
        connector_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ConnectorResponse:
        """
        Create a new llm connector

        Attributes:

            connector_name: The profile name of the connector to create.
            connector_body: The body of the connector to create.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/llm_connector/create",
            body=await async_maybe_transform(
                {
                    "connector_body": connector_body,
                    "connector_name": connector_name,
                },
                llm_connector_create_params.LlmConnectorCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConnectorResponse,
        )

    async def update(
        self,
        *,
        connector_body: OpenAIConfigParam,
        connector_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ConnectorResponse:
        """
        Update a llm connector

        Attributes:

            connector_name: The profile name of the connector to update.
            connector_body: The body of the connector to update.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/llm_connector/update",
            body=await async_maybe_transform(
                {
                    "connector_body": connector_body,
                    "connector_name": connector_name,
                },
                llm_connector_update_params.LlmConnectorUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConnectorResponse,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LlmConnectorListResponse:
        """List all the llm connectors"""
        return await self._post(
            "/llm_connector/list",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LlmConnectorListResponse,
        )

    async def delete(
        self,
        *,
        connector_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ConnectorResponse:
        """
        Delete a llm connector

        Attributes:

            connector_name: The profile name of the connector to delete.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/llm_connector/delete",
            body=await async_maybe_transform(
                {"connector_name": connector_name}, llm_connector_delete_params.LlmConnectorDeleteParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConnectorResponse,
        )


class LlmConnectorResourceWithRawResponse:
    def __init__(self, llm_connector: LlmConnectorResource) -> None:
        self._llm_connector = llm_connector

        self.create = to_raw_response_wrapper(
            llm_connector.create,
        )
        self.update = to_raw_response_wrapper(
            llm_connector.update,
        )
        self.list = to_raw_response_wrapper(
            llm_connector.list,
        )
        self.delete = to_raw_response_wrapper(
            llm_connector.delete,
        )


class AsyncLlmConnectorResourceWithRawResponse:
    def __init__(self, llm_connector: AsyncLlmConnectorResource) -> None:
        self._llm_connector = llm_connector

        self.create = async_to_raw_response_wrapper(
            llm_connector.create,
        )
        self.update = async_to_raw_response_wrapper(
            llm_connector.update,
        )
        self.list = async_to_raw_response_wrapper(
            llm_connector.list,
        )
        self.delete = async_to_raw_response_wrapper(
            llm_connector.delete,
        )


class LlmConnectorResourceWithStreamingResponse:
    def __init__(self, llm_connector: LlmConnectorResource) -> None:
        self._llm_connector = llm_connector

        self.create = to_streamed_response_wrapper(
            llm_connector.create,
        )
        self.update = to_streamed_response_wrapper(
            llm_connector.update,
        )
        self.list = to_streamed_response_wrapper(
            llm_connector.list,
        )
        self.delete = to_streamed_response_wrapper(
            llm_connector.delete,
        )


class AsyncLlmConnectorResourceWithStreamingResponse:
    def __init__(self, llm_connector: AsyncLlmConnectorResource) -> None:
        self._llm_connector = llm_connector

        self.create = async_to_streamed_response_wrapper(
            llm_connector.create,
        )
        self.update = async_to_streamed_response_wrapper(
            llm_connector.update,
        )
        self.list = async_to_streamed_response_wrapper(
            llm_connector.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            llm_connector.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["OpenAIConfig"]


class OpenAIConfig(BaseModel):
    api_key: str

    rpm_completion: int

    tpm_completion: int

    llm_type: Optional[str] = FieldInfo(alias="llmType", default=None)

    rpm_embedding: Optional[int] = None

    temperature: Optional[float] = None

    tpm_embedding: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.


from .._models import BaseModel

__all__ = ["DatasliceGetFileCountResponse"]


class DatasliceGetFileCountResponse(BaseModel):
    file_count: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Optional
from typing_extensions import Required, TypedDict

__all__ = ["GraphCreateParams"]


class GraphCreateParams(TypedDict, total=False):
    graph_name: Required[str]

    graph_data: Optional[Dict[str, object]]

    graph_description: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .export import (
    ExportResource,
    AsyncExportResource,
    ExportResourceWithRawResponse,
    AsyncExportResourceWithRawResponse,
    ExportResourceWithStreamingResponse,
    AsyncExportResourceWithStreamingResponse,
)
from .dataslice import (
    DatasliceResource,
    AsyncDatasliceResource,
    DatasliceResourceWithRawResponse,
    AsyncDatasliceResourceWithRawResponse,
    DatasliceResourceWithStreamingResponse,
    AsyncDatasliceResourceWithStreamingResponse,
)

__all__ = [
    "ExportResource",
    "AsyncExportResource",
    "ExportResourceWithRawResponse",
    "AsyncExportResourceWithRawResponse",
    "ExportResourceWithStreamingResponse",
    "AsyncExportResourceWithStreamingResponse",
    "DatasliceResource",
    "AsyncDatasliceResource",
    "DatasliceResourceWithRawResponse",
    "AsyncDatasliceResourceWithRawResponse",
    "DatasliceResourceWithStreamingResponse",
    "AsyncDatasliceResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["ExportExportMetadataParams"]


class ExportExportMetadataParams(TypedDict, total=False):
    vdb_profile_name: Required[str]

    dataslice_id: Optional[str]

    export_file_level: bool

    export_format: Optional[Literal["json", "csv"]]

    selected_metadata_fields: Optional[List[str]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import TypedDict

__all__ = ["GraphListParams"]


class GraphListParams(TypedDict, total=False):
    graph_names: Optional[List[str]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Optional

import httpx

from ...types import (
    metadata_list_params,
    metadata_delete_params,
    metadata_upsert_params,
    metadata_list_paginated_params,
)
from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import (
    maybe_transform,
    async_maybe_transform,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .deasy_select import (
    DeasySelectResource,
    AsyncDeasySelectResource,
    DeasySelectResourceWithRawResponse,
    AsyncDeasySelectResourceWithRawResponse,
    DeasySelectResourceWithStreamingResponse,
    AsyncDeasySelectResourceWithStreamingResponse,
)
from ..._base_client import make_request_options
from ...types.condition_input_param import ConditionInputParam
from ...types.metadata_list_response import MetadataListResponse
from ...types.metadata_delete_response import MetadataDeleteResponse
from ...types.metadata_upsert_response import MetadataUpsertResponse
from ...types.metadata_list_paginated_response import MetadataListPaginatedResponse

__all__ = ["MetadataResource", "AsyncMetadataResource"]


class MetadataResource(SyncAPIResource):
    @cached_property
    def deasy_select(self) -> DeasySelectResource:
        return DeasySelectResource(self._client)

    @cached_property
    def with_raw_response(self) -> MetadataResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return MetadataResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MetadataResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return MetadataResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        vdb_profile_name: str,
        conditions: Optional[ConditionInputParam] | NotGiven = NOT_GIVEN,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        include_chunk_level: Optional[bool] | NotGiven = NOT_GIVEN,
        tag_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MetadataListResponse:
        """
        Get paginated filtered metadata based on conditions

        Attributes:

            vdb_profile_name: The name of the vdb profile to include in the dataslice.
            dataslice_id: The dataslice for getting files from.
            conditions: The conditions to filter the files by.
            tag_names: The names of the tags to include in the metadata.
            include_chunk_level: Whether to include the chunk-level metadata.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/metadata/list",
            body=maybe_transform(
                {
                    "vdb_profile_name": vdb_profile_name,
                    "conditions": conditions,
                    "dataslice_id": dataslice_id,
                    "include_chunk_level": include_chunk_level,
                    "tag_names": tag_names,
                },
                metadata_list_params.MetadataListParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MetadataListResponse,
        )

    def delete(
        self,
        *,
        vdb_profile_name: str,
        conditions: Optional[ConditionInputParam] | NotGiven = NOT_GIVEN,
        file_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        tags: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MetadataDeleteResponse:
        """
        Delete metadata for specified files and tags

        Attributes: vector_db_config: The vector database configuration to use.
        file_names: The files to delete the metadata for. tags: The tags to delete the
        metadata for. conditions: The conditions to delete the metadata for.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/metadata/delete",
            body=maybe_transform(
                {
                    "vdb_profile_name": vdb_profile_name,
                    "conditions": conditions,
                    "file_names": file_names,
                    "tags": tags,
                },
                metadata_delete_params.MetadataDeleteParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MetadataDeleteResponse,
        )

    def list_paginated(
        self,
        *,
        vdb_profile_name: str,
        conditions: Optional[ConditionInputParam] | NotGiven = NOT_GIVEN,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        include_chunk_level: Optional[bool] | NotGiven = NOT_GIVEN,
        limit: Optional[int] | NotGiven = NOT_GIVEN,
        offset: Optional[int] | NotGiven = NOT_GIVEN,
        tag_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MetadataListPaginatedResponse:
        """
        Get paginated filtered metadata based on conditions

        Attributes:

            vdb_profile_name: The name of the vdb profile to include in the dataslice.
            dataslice_id: The dataslice for getting files from.
            conditions: The conditions to filter the files by.
            tag_names: The names of the tags to include in the metadata.
            include_chunk_level: Whether to include the chunk-level metadata.
            offset: The offset to start the pagination from.
            limit: The limit to the number of metadata to return.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/metadata/list_paginated",
            body=maybe_transform(
                {
                    "vdb_profile_name": vdb_profile_name,
                    "conditions": conditions,
                    "dataslice_id": dataslice_id,
                    "include_chunk_level": include_chunk_level,
                    "limit": limit,
                    "offset": offset,
                    "tag_names": tag_names,
                },
                metadata_list_paginated_params.MetadataListPaginatedParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MetadataListPaginatedResponse,
        )

    def upsert(
        self,
        *,
        metadata: Dict[str, Dict[str, metadata_upsert_params.MetadataMetadataItem]],
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        vdb_profile_name: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MetadataUpsertResponse:
        """
        Upsert metadata for files and tags

        Attributes:

            vdb_profile_name: The name of the vdb profile to include in the dataslice.
            dataslice_id: The dataslice for getting files from.
            metadata: The metadata to upsert with the form {file_name: {tag_name: tag_value}}.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/metadata/upsert",
            body=maybe_transform(
                {
                    "metadata": metadata,
                    "dataslice_id": dataslice_id,
                    "vdb_profile_name": vdb_profile_name,
                },
                metadata_upsert_params.MetadataUpsertParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MetadataUpsertResponse,
        )


class AsyncMetadataResource(AsyncAPIResource):
    @cached_property
    def deasy_select(self) -> AsyncDeasySelectResource:
        return AsyncDeasySelectResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncMetadataResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return AsyncMetadataResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMetadataResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return AsyncMetadataResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        vdb_profile_name: str,
        conditions: Optional[ConditionInputParam] | NotGiven = NOT_GIVEN,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        include_chunk_level: Optional[bool] | NotGiven = NOT_GIVEN,
        tag_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MetadataListResponse:
        """
        Get paginated filtered metadata based on conditions

        Attributes:

            vdb_profile_name: The name of the vdb profile to include in the dataslice.
            dataslice_id: The dataslice for getting files from.
            conditions: The conditions to filter the files by.
            tag_names: The names of the tags to include in the metadata.
            include_chunk_level: Whether to include the chunk-level metadata.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/metadata/list",
            body=await async_maybe_transform(
                {
                    "vdb_profile_name": vdb_profile_name,
                    "conditions": conditions,
                    "dataslice_id": dataslice_id,
                    "include_chunk_level": include_chunk_level,
                    "tag_names": tag_names,
                },
                metadata_list_params.MetadataListParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MetadataListResponse,
        )

    async def delete(
        self,
        *,
        vdb_profile_name: str,
        conditions: Optional[ConditionInputParam] | NotGiven = NOT_GIVEN,
        file_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        tags: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MetadataDeleteResponse:
        """
        Delete metadata for specified files and tags

        Attributes: vector_db_config: The vector database configuration to use.
        file_names: The files to delete the metadata for. tags: The tags to delete the
        metadata for. conditions: The conditions to delete the metadata for.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/metadata/delete",
            body=await async_maybe_transform(
                {
                    "vdb_profile_name": vdb_profile_name,
                    "conditions": conditions,
                    "file_names": file_names,
                    "tags": tags,
                },
                metadata_delete_params.MetadataDeleteParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MetadataDeleteResponse,
        )

    async def list_paginated(
        self,
        *,
        vdb_profile_name: str,
        conditions: Optional[ConditionInputParam] | NotGiven = NOT_GIVEN,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        include_chunk_level: Optional[bool] | NotGiven = NOT_GIVEN,
        limit: Optional[int] | NotGiven = NOT_GIVEN,
        offset: Optional[int] | NotGiven = NOT_GIVEN,
        tag_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MetadataListPaginatedResponse:
        """
        Get paginated filtered metadata based on conditions

        Attributes:

            vdb_profile_name: The name of the vdb profile to include in the dataslice.
            dataslice_id: The dataslice for getting files from.
            conditions: The conditions to filter the files by.
            tag_names: The names of the tags to include in the metadata.
            include_chunk_level: Whether to include the chunk-level metadata.
            offset: The offset to start the pagination from.
            limit: The limit to the number of metadata to return.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/metadata/list_paginated",
            body=await async_maybe_transform(
                {
                    "vdb_profile_name": vdb_profile_name,
                    "conditions": conditions,
                    "dataslice_id": dataslice_id,
                    "include_chunk_level": include_chunk_level,
                    "limit": limit,
                    "offset": offset,
                    "tag_names": tag_names,
                },
                metadata_list_paginated_params.MetadataListPaginatedParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MetadataListPaginatedResponse,
        )

    async def upsert(
        self,
        *,
        metadata: Dict[str, Dict[str, metadata_upsert_params.MetadataMetadataItem]],
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        vdb_profile_name: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> MetadataUpsertResponse:
        """
        Upsert metadata for files and tags

        Attributes:

            vdb_profile_name: The name of the vdb profile to include in the dataslice.
            dataslice_id: The dataslice for getting files from.
            metadata: The metadata to upsert with the form {file_name: {tag_name: tag_value}}.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/metadata/upsert",
            body=await async_maybe_transform(
                {
                    "metadata": metadata,
                    "dataslice_id": dataslice_id,
                    "vdb_profile_name": vdb_profile_name,
                },
                metadata_upsert_params.MetadataUpsertParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MetadataUpsertResponse,
        )


class MetadataResourceWithRawResponse:
    def __init__(self, metadata: MetadataResource) -> None:
        self._metadata = metadata

        self.list = to_raw_response_wrapper(
            metadata.list,
        )
        self.delete = to_raw_response_wrapper(
            metadata.delete,
        )
        self.list_paginated = to_raw_response_wrapper(
            metadata.list_paginated,
        )
        self.upsert = to_raw_response_wrapper(
            metadata.upsert,
        )

    @cached_property
    def deasy_select(self) -> DeasySelectResourceWithRawResponse:
        return DeasySelectResourceWithRawResponse(self._metadata.deasy_select)


class AsyncMetadataResourceWithRawResponse:
    def __init__(self, metadata: AsyncMetadataResource) -> None:
        self._metadata = metadata

        self.list = async_to_raw_response_wrapper(
            metadata.list,
        )
        self.delete = async_to_raw_response_wrapper(
            metadata.delete,
        )
        self.list_paginated = async_to_raw_response_wrapper(
            metadata.list_paginated,
        )
        self.upsert = async_to_raw_response_wrapper(
            metadata.upsert,
        )

    @cached_property
    def deasy_select(self) -> AsyncDeasySelectResourceWithRawResponse:
        return AsyncDeasySelectResourceWithRawResponse(self._metadata.deasy_select)


class MetadataResourceWithStreamingResponse:
    def __init__(self, metadata: MetadataResource) -> None:
        self._metadata = metadata

        self.list = to_streamed_response_wrapper(
            metadata.list,
        )
        self.delete = to_streamed_response_wrapper(
            metadata.delete,
        )
        self.list_paginated = to_streamed_response_wrapper(
            metadata.list_paginated,
        )
        self.upsert = to_streamed_response_wrapper(
            metadata.upsert,
        )

    @cached_property
    def deasy_select(self) -> DeasySelectResourceWithStreamingResponse:
        return DeasySelectResourceWithStreamingResponse(self._metadata.deasy_select)


class AsyncMetadataResourceWithStreamingResponse:
    def __init__(self, metadata: AsyncMetadataResource) -> None:
        self._metadata = metadata

        self.list = async_to_streamed_response_wrapper(
            metadata.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            metadata.delete,
        )
        self.list_paginated = async_to_streamed_response_wrapper(
            metadata.list_paginated,
        )
        self.upsert = async_to_streamed_response_wrapper(
            metadata.upsert,
        )

    @cached_property
    def deasy_select(self) -> AsyncDeasySelectResourceWithStreamingResponse:
        return AsyncDeasySelectResourceWithStreamingResponse(self._metadata.deasy_select)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Union, Iterable, Optional
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = [
    "DeasySelectQueryParams",
    "TagDistributions",
    "TagDistributionsData",
    "TagDistributionsDataValues",
    "TagSchema",
]


class DeasySelectQueryParams(TypedDict, total=False):
    query: Required[str]

    vdb_profile_name: Required[str]

    max_filter_values_to_choose: Optional[int]

    max_filters_to_choose: Optional[int]

    max_search_reduction: Optional[float]

    min_filter_values_to_choose: Optional[int]

    min_filters_to_choose: Optional[int]

    min_search_reduction: Optional[float]

    return_type: Optional[Literal["results", "condition", "both"]]

    tag_distributions: Optional[TagDistributions]
    """Complete tag distribution data structure for analyzing filter impacts.

    Maps field names to their value distributions. Used for estimating search
    reductions without executing filters.
    """

    tag_names: Optional[List[str]]

    tag_schemas: Optional[Iterable[TagSchema]]


class TagDistributionsDataValues(TypedDict, total=False):
    file_count: Required[int]

    chunk_count: Optional[int]

    percentage: Optional[float]


class TagDistributionsData(TypedDict, total=False):
    values: Required[Dict[str, TagDistributionsDataValues]]

    coverage_percentage: Optional[float]

    total_count: Optional[int]


class TagDistributions(TypedDict, total=False):
    data: Dict[str, TagDistributionsData]


class TagSchema(TypedDict, total=False):
    description: Required[str]

    name: Required[str]

    output_type: Required[str]

    available_values: Optional[List[str]]

    created_at: Annotated[Union[str, datetime, None], PropertyInfo(format="iso8601")]

    date_format: Optional[str]

    examples: Optional[List[Union[str, Dict[str, object]]]]

    max_values: Annotated[Union[int, str, Iterable[object], None], PropertyInfo(alias="maxValues")]

    neg_examples: Optional[List[str]]

    retry_feedback: Optional[Dict[str, object]]

    tag_id: Optional[str]

    tuned: Optional[int]

    updated_at: Annotated[Union[str, datetime, None], PropertyInfo(format="iso8601")]

    username: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.


from .._models import BaseModel

__all__ = ["GraphOperationResponse"]


class GraphOperationResponse(BaseModel):
    graph_name: str
